summaryrefslogtreecommitdiffstats
path: root/lib/kformula/formulacursor.cc
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:32:11 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:32:11 -0600
commit94844816550ad672ccfcdc25659c625546239998 (patch)
treee35fc60fd736c645d59f6408af032774ad8023d3 /lib/kformula/formulacursor.cc
parent2a811c38c74c03648ecf857e566c44483cbad706 (diff)
downloadkoffice-94844816550ad672ccfcdc25659c625546239998.tar.gz
koffice-94844816550ad672ccfcdc25659c625546239998.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'lib/kformula/formulacursor.cc')
-rw-r--r--lib/kformula/formulacursor.cc20
1 files changed, 10 insertions, 10 deletions
diff --git a/lib/kformula/formulacursor.cc b/lib/kformula/formulacursor.cc
index 9fe3afbd..2257d262 100644
--- a/lib/kformula/formulacursor.cc
+++ b/lib/kformula/formulacursor.cc
@@ -301,21 +301,21 @@ void FormulaCursor::insert(BasicElement* child, Direction direction)
insert(list, direction);
}
-void FormulaCursor::insert(TQPtrList<BasicElement>& tqchildren,
+void FormulaCursor::insert(TQPtrList<BasicElement>& children,
Direction direction)
{
assert( !isReadOnly() );
BasicElement* element = getElement();
- element->insert(this, tqchildren, direction);
+ element->insert(this, children, direction);
}
/**
* Removes the current selected tqchildren and returns them.
* The cursor needs to be normal (that is be inside a SequenceElement)
* for this to have any effect.
*/
-void FormulaCursor::remove(TQPtrList<BasicElement>& tqchildren,
+void FormulaCursor::remove(TQPtrList<BasicElement>& children,
Direction direction)
{
assert( !isReadOnly() );
@@ -328,12 +328,12 @@ void FormulaCursor::remove(TQPtrList<BasicElement>& tqchildren,
BasicElement* parent = sequence->getParent();
if (parent != 0) {
parent->selectChild(this, sequence);
- parent->remove(this, tqchildren, direction);
+ parent->remove(this, children, direction);
return;
}
}
else {
- sequence->remove(this, tqchildren, direction);
+ sequence->remove(this, children, direction);
}
}
}
@@ -383,18 +383,18 @@ void FormulaCursor::replaceSelectionWith(BasicElement* element,
BasicElement* FormulaCursor::replaceByMainChildContent(Direction direction)
{
assert( !isReadOnly() );
- TQPtrList<BasicElement> tqchildrenList;
+ TQPtrList<BasicElement> childrenList;
TQPtrList<BasicElement> list;
BasicElement* element = getElement();
SequenceElement* mainChild = element->getMainChild();
if ((mainChild != 0) && (mainChild->countChildren() > 0)) {
mainChild->selectAllChildren(this);
- remove(tqchildrenList);
+ remove(childrenList);
}
element->getParent()->selectChild(this, element);
setSelection(false);
remove(list);
- insert(tqchildrenList, direction);
+ insert(childrenList, direction);
if (list.count() > 0) {
return list.take(0);
}
@@ -582,7 +582,7 @@ MatrixElement* FormulaCursor::getActiveMatrixElement()
}
/**
* The element is going to leave the formula with and all its tqchildren.
*/
void FormulaCursor::elementWillVanish(BasicElement* element)
{
@@ -301,21 +301,21 @@ void FormulaCursor::insert(BasicElement* child, Direction direction)
}
/**
- * Removes the current selected tqchildren and returns them.
+ * Removes the current selected children and returns them.
* The cursor needs to be normal (that is be inside a SequenceElement)
* for this to have any effect.
@@ -582,7 +582,7 @@ MatrixElement* FormulaCursor::getActiveMatrixElement()
}
/**
- * The element is going to leave the formula with and all its tqchildren.
+ * The element is going to leave the formula with and all its children.
*/
void FormulaCursor::elementWillVanish(BasicElement* element)